============
Installation
============

At the command line::

    $ pip install twodolib
    # or
    $ pip install --user twodolib

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv twodolib
    (twodolib)$ pip install twodolib

